<?php
/**
 * Welcome Screen Class
 */
  if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists('Fortune_welcome')) {
class Fortune_welcome {
	
	public $admin_notices = array();
	/**
	 * Constructor for the welcome screen
	 */
	public function __construct() {

		/* create dashbord page */
		add_action( 'admin_menu', array( $this, 'Fortune_lite_welcome_register_menu' ) );

		/* activation notice */
		add_action( 'load-themes.php', array( $this, 'Fortune_lite_activation_admin_notice' ) );

		/* enqueue script and style for welcome screen */
		add_action( 'admin_enqueue_scripts', array( $this, 'Fortune_lite_welcome_style_and_scripts' ) );

		/* load welcome screen */
		add_action( 'Fortune_lite_welcome', array( $this, 'Fortune_lite_welcome_getting_started' ), 10 );
		
		add_action( 'Fortune_lite_welcome', array( $this, 'Fortune_lite_welcome_changelog' ), 50 );				
		}

	/**
	 * Creates the dashboard page
	 * @see  add_theme_page()
	 * @since 1.8.2.4
	 */
	public function Fortune_lite_welcome_register_menu() {
		add_theme_page( 'About fortune', 'About Fortune', 'activate_plugins', 'fortune-welcome', array( $this, 'Fortune_lite_welcome_screen' ) );
	}

	/**
	 * Adds an admin notice upon successful activation.
	 * @since 1.8.2.4
	 */
	public function Fortune_lite_activation_admin_notice() {
		global $pagenow;

		if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
			add_action( 'admin_notices', array( $this, 'Fortune_lite_welcome_admin_notice' ), 99 );
		}
	}

	/**
	 * Display an admin notice linking to the welcome screen
	 * @since 1.8.2.4
	 */
	public function Fortune_lite_welcome_admin_notice() {
		?>
			<div class="updated notice is-dismissible">
				<p><?php echo sprintf( esc_html__( 'Welcome! Thank you for choosing Fortune Theme! To fully take advantage of the best our theme can offer please make sure you visit our %swelcome page%s.', 'fortune' ), '<a href="' . esc_url( admin_url( 'themes.php?page=fortune-welcome' ) ) . '">', '</a>' ); ?></p>
				<p><a href="<?php echo esc_url( admin_url( 'themes.php?page=fortune-welcome' ) ); ?>" class="button" style="text-decoration: none;"><?php _e( 'Get started with fortune', 'fortune' ); ?></a></p>
			</div>
		<?php
	}

	/**
	 * Load welcome screen css and javascript
	 * @since  1.8.2.4
	 */
	public function Fortune_lite_welcome_style_and_scripts( $hook_suffix ) {

		if ( 'appearance_page_fortune-welcome' == $hook_suffix ) {
			wp_enqueue_style( 'fortune-welcome-screen-css', get_template_directory_uri() . '/inc/welcome-screen/css/welcome.css' );
			wp_enqueue_script( 'fortune-welcome-screen-js', get_template_directory_uri() . '/inc/welcome-screen/js/welcome.js', array('jquery') );

			global $Fortune_required_actions;

			$nr_actions_required = 0;

			wp_localize_script( 'fortune-welcome-screen-js', 'fortuneLiteWelcomeScreenObject', array(
				'nr_actions_required' => $nr_actions_required,
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'template_directory' => get_template_directory_uri(),
				'no_required_actions_text' => __( 'Hooray! There are no required actions for you right now.','fortune' )
			) );
		}
	}


	/**
	 * Welcome screen content
	 * @since 1.8.2.4
	 */
	public function Fortune_lite_welcome_screen() {

		require_once( ABSPATH . 'wp-load.php' );
		require_once( ABSPATH . 'wp-admin/admin.php' );
		require_once( ABSPATH . 'wp-admin/admin-header.php' );
		?>

		<ul class="fortune-lite-nav-tabs" role="tablist">
			<li role="presentation" class="active"><a href="#getting_started" aria-controls="getting_started" role="tab" data-toggle="tab"><?php esc_html_e( 'Getting started','fortune'); ?></a></li>
			<li role="presentation"><a href="#changelog" aria-controls="changelog" role="tab" data-toggle="tab"><?php esc_html_e( 'Changelog','fortune'); ?></a></li>
		</ul>

		<div class="fortune-lite-tab-content">

			<?php
			/**
			 * @hooked Fortune_lite_welcome_getting_started - 10
			 * @hooked Fortune_lite_welcome_actions_required - 20
			 * @hooked Fortune_lite_welcome_changelog - 50
			 * @hooked Fortune_lite_welcome_free_pro - 60
			 */
			do_action( 'Fortune_lite_welcome' ); ?>

		</div>
		<?php
	}


	/**
	 * Getting started
	 * @since 1.8.2.4
	 */
	public function Fortune_lite_welcome_getting_started() {
		require_once( get_template_directory() . '/inc/welcome-screen/sections/getting-started.php' );
	}

	/**
	 * Changelog
	 * @since 1.8.2.4
	 */
	public function Fortune_lite_welcome_changelog() {
		require_once( get_template_directory() . '/inc/welcome-screen/sections/changelog.php' );
	}

}

$GLOBALS['Fortune_welcome'] = new Fortune_welcome();
}
?>